import React from 'react';
import { StyleSheet, View } from 'react-native';
import FlyingPiece from './FlyingPiece';
import { BUFFER_CONSTANT, CHARACTER_SIZE, HEIGHT_BUFFER, SECOND, WIDTH_BUFFER, WINDOW_HEIGHT_WITH_BUFFER, WINDOW_WIDTH_WITH_BUFFER, } from './constants';
const MIN_FALL_DELAY = 1 * SECOND;
const MIN_FALL_DURATION = 8 * SECOND;
const MIN_SHAKE_DELAY = 1 * SECOND;
const MIN_SHAKE_DURATION = 3 * SECOND;
const MIN_AMPLITUDE = 1;
const MIN_SIZE = 1;
const MAX_FALL_DELAY = 8 * SECOND;
const MAX_FALL_DURATION = 12 * SECOND;
const MAX_SHAKE_DELAY = 4 * SECOND;
const MAX_SHAKE_DURATION = 2 * SECOND;
const MAX_AMPLITUDE = 50;
const MAX_CHARACTER = WINDOW_WIDTH_WITH_BUFFER /
    (MAX_AMPLITUDE / (MAX_AMPLITUDE * BUFFER_CONSTANT));
const MAX_SIZE = WINDOW_WIDTH_WITH_BUFFER / MAX_CHARACTER + CHARACTER_SIZE;
const Confetti = ({ isEnabled, color, character = '❅', imageComponent, effect = 'snow', }) => {
    const flyingPiecesStyle = !!color ? { color } : undefined;
    const flyingPieces = _getFlyingPieces();
    if (isEnabled) {
        return (React.createElement(View, { style: styles.view, pointerEvents: "none" }, flyingPieces.map((item, i) => {
            const { size, fallDelay, shakeDelay, fallDuration, amplitude, shakeDuration, } = item;
            return (React.createElement(FlyingPiece, { key: `FlyingPiece-${i}`, character: character, size: size, fallDelay: fallDelay, fallDuration: fallDuration, shakeDelay: shakeDelay, shakeDuration: shakeDuration, style: flyingPiecesStyle, imageComponent: imageComponent, amplitude: amplitude, effect: effect }));
        })));
    }
    return null;
};
const _getRandomNumber = (min, max) => {
    return Math.floor(Math.random() * (max - min + 1)) + min;
};
const _getFlyingPieces = () => {
    let piecesArr = [];
    for (let i = 0; i < MAX_CHARACTER; i++) {
        piecesArr.push({
            size: _getRandomNumber(MIN_SIZE, MAX_SIZE),
            fallDelay: _getRandomNumber(MIN_FALL_DELAY, MAX_FALL_DELAY),
            shakeDelay: _getRandomNumber(MIN_SHAKE_DELAY, MAX_SHAKE_DELAY),
            shakeDuration: _getRandomNumber(MIN_SHAKE_DURATION, MAX_SHAKE_DURATION),
            fallDuration: _getRandomNumber(MIN_FALL_DURATION, MAX_FALL_DURATION),
            amplitude: _getRandomNumber(MIN_AMPLITUDE, MAX_AMPLITUDE),
        });
    }
    return piecesArr;
};
const styles = StyleSheet.create({
    view: {
        flexDirection: 'row',
        zIndex: 1,
        elevation: 9999,
        position: 'absolute',
        top: -HEIGHT_BUFFER / 2,
        left: -WIDTH_BUFFER / 2,
        width: WINDOW_WIDTH_WITH_BUFFER,
        height: WINDOW_HEIGHT_WITH_BUFFER,
        backgroundColor: 'transparent',
    },
});
export default Confetti;
//# sourceMappingURL=Confetti.js.map